#
# spec file for package python-python-pptx
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-python-pptx
Version:        1.0.2
Release:        1.3
Summary:        Generate and manipulate Open XML PowerPoint (pptx) files
License:        MIT
URL:            http://github.com/scanny/python-pptx
Source:         https://files.pythonhosted.org/packages/source/p/python-pptx/python_pptx-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 61.0.0}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module lxml >= 3.1.0}
BuildRequires:  %{python_module Pillow >= 3.3.2}
BuildRequires:  %{python_module XlsxWriter >= 0.5.7}
BuildRequires:  %{python_module behave}
BuildRequires:  %{python_module pyparsing >= 2.0.1}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module typing_extensions >= 4.9.0}
# /SECTION
BuildRequires:  fdupes
Requires:       python-Pillow >= 3.3.2
Requires:       python-XlsxWriter >= 0.5.7
Requires:       python-lxml >= 3.1.0
Requires:       python-typing_extensions >= 4.9.0
BuildArch:      noarch
%python_subpackages

%description
Create, read, and update PowerPoint 2007+ (.pptx) files.

%prep
%autosetup -p1 -n python_pptx-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc HISTORY.rst README.rst
%{python_sitelib}/*pptx*

%changelog
* Fri Sep 27 2024 Thiago Bertoldi <thiago.bertoldi@suse.com>
- Remove utc.patch (not necessary since 1.0.0)
- Update to 1.0.2 (2024-08-07)
  * fix: #1003 restore read-only enum members
- Update to 1.0.1 (2024-08-05)
  * fix: #1000 add py.typed
- Update to 1.0.0 (2024-08-03)
  * fix: #929 raises on JPEG with image/jpg MIME-type
  * fix: #943 remove mention of a Px Length subtype
  * fix: #972 next-slide-id fails in rare cases
  * fix: #990 do not require strict timestamps for Zip
  * Add type annotations
* Thu Sep 26 2024 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- fixed %%{?sle15_python_module_pythons}
* Fri Mar 15 2024 Markéta Machová <mmachova@suse.com>
- Add patch utc.patch to fix the behavior on Python 3.12
* Tue Dec 26 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.23:
  * fix: #912 Pillow<=9.5 constraint entails security
    vulnerability
  * Add #909 Add imgW, imgH params to `shapes.add_ole_object()`
  * fix: #754 _Relationships.items() raises
  * fix: #758 quote in autoshape name must be escaped
  * fix: #746 update Python 3.x support in docs
  * fix: #748 setup's `license` should be short string
  * fix: #762 AttributeError: module 'collections' has no
    attribute 'abc'
* Thu Oct  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.6.21 (2021-09-20)
  Fix #741 _DirPkgReader must implement .__contains__()
- Update to 0.6.20 (2021-09-14)
  Fix #206 accommodate NULL target-references in relationships.
  Fix #223 escape image filename that appears as literal in XML.
  Fix #517 option to display chart categories/values in reverse order.
  Major refactoring of ancient package loading code.
* Mon Apr 11 2022 Markéta Machová <mmachova@suse.com>
- do not use mock
* Tue Aug 24 2021 Martin Hauke <mardnh@gmx.de>
- Initial package, version 0.6.19
